'use strict';

var util = require('util');
var fs = require('graceful-fs');
var pify = require('pify');
var steno = require('steno');
var Base = require('./Base');

var readFile = pify(fs.readFile);
var writeFile = pify(steno.writeFile);

// Same code as in FileAsync, minus `await`

function FileAsync(source) {
  Base.call(this, source);
}
util.inherits(FileAsync, Base);

FileAsync.prototype.read = function() {
  // fs.exists is deprecated but not fs.existsSync
  if (fs.existsSync(this.source)) {
    // Read database
    return readFile(this.source, 'utf8')
      .then(function(data) {
        // Handle blank file
        var trimmed = data.trim();
        return trimmed ? this.deserialize(trimmed) : this.defaultValue;
      })
      .catch(function(e) {
        if (e instanceof SyntaxError) {
          e.message = `Malformed JSON in file: ${this.source}\n${e.message}`
        }
        throw e
      });
  } else {
    // Initialize
    return writeFile(this.source, this.serialize(this.defaultValue)).then(
      () => this.defaultValue
    );
  }
};

FileAsync.prototype.write = function(data) {
  return writeFile(this.source, this.serialize(data))
};