'use strict';

var util = require('util');
var fs = require('graceful-fs');
var Base = require('./Base');

var readFile = fs.readFileSync;
var writeFile = fs.writeFileSync;

// Same code as in FileAsync, minus `await`

function FileSync(source) {
  Base.call(this, source);
}
util.inherits(FileSync, Base);

FileSync.prototype.read = function() {
  if (fs.existsSync(this.source)) {
    // Read database
    try {
      var data = readFile(this.source, 'utf-8').trim();
      // Handle blank file
      return data ? this.deserialize(data) : this.defaultValue;
    } catch (e) {
      if (e instanceof SyntaxError) {
        e.message = `Malformed JSON in file: ${this.source}\n${e.message}`;
      }
      throw e;
    }
  } else {
    // Initialize
    writeFile(this.source, this.serialize(this.defaultValue));
    return this.defaultValue;
  }
};

FileSync.prototype.write = function(data) {
  return writeFile(this.source, this.serialize(data));
};

module.exports = FileSync;